==> liitos-2023.5.10.tar.gz: liitos-2023.5.10/README.md <==
# Liitos

Splice (Finnish: liitos) contributions.

[License: MIT](https://git.sr.ht/~sthagen/liitos/tree/default/item/LICENSE)

Third party dependencies are documented in the folder [third-party](docs/third-party/README.md).

[![version](https://img.shields.io/pypi/v/liitos.svg?style=flat)](https://pypi.python.org/pypi/liitos/)
[![downloads](https://pepy.tech/badge/liitos/month)](https://pepy.tech/project/liitos)
[![wheel](https://img.shields.io/pypi/wheel/liitos.svg?style=flat)](https://pypi.python.org/pypi/liitos/)
[![supported-versions](https://img.shields.io/pypi/pyversions/liitos.svg?style=flat)](https://pypi.python.org/pypi/liitos/)
[![supported-implementations](https://img.shields.io/pypi/implementation/liitos.svg?style=flat)](https://pypi.python.org/pypi/liitos/)

## Documentation

User and developer [documentation of liitos](https://codes.dilettant.life/docs/liitos).

## Bug Tracker

Any feature requests or bug reports shall go to the [todos of liitos](https://todo.sr.ht/~sthagen/liitos).

## Primary Source repository

The main source of `liitos` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clones of `liitos` are:

* [on codeberg](https://codeberg.org/sthagen/liitos) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/liitos) - a collection of tools useful for software development.

## Contributions

Please do not submit "pull requests" (I found no way to disable that "feature" on GitHub).
If you like to share small changes under the repositories license please kindly do so by sending a patchset.
You can either send such a patchset per email using [git send-email](https://git-send-email.io) or 
if you are a sourcehut user by selecting "Prepare a patchset" on the summary page of your fork at [sourcehut](https://git.sr.ht/).

# Status

Experimental.

**Note**: The default branch is `default`.

==> liitos-2023.10.5.tar.gz: liitos-2023.10.5/README.md <==
# Liitos

Splice (Finnish: liitos) contributions.

[License: MIT](https://git.sr.ht/~sthagen/liitos/tree/default/item/LICENSE)

Third party dependencies are documented in the folder [third-party](docs/third-party/README.md).

[![version](https://img.shields.io/pypi/v/liitos.svg?style=flat)](https://pypi.python.org/pypi/liitos/)
[![downloads](https://static.pepy.tech/badge/liitos/month)](https://pepy.tech/project/liitos)
[![wheel](https://img.shields.io/pypi/wheel/liitos.svg?style=flat)](https://pypi.python.org/pypi/liitos/)
[![supported-versions](https://img.shields.io/pypi/pyversions/liitos.svg?style=flat)](https://pypi.python.org/pypi/liitos/)
[![supported-implementations](https://img.shields.io/pypi/implementation/liitos.svg?style=flat)](https://pypi.python.org/pypi/liitos/)
[![maintenance-status](https://img.shields.io/github/commit-activity/y/sthagen/liitos.svg?style=flat)](https://git.sr.ht/~sthagen/liitos/log)

## Documentation

User and developer [documentation of liitos](https://codes.dilettant.life/docs/liitos).

## Bug Tracker

Any feature requests or bug reports shall go to the [todos of liitos](https://todo.sr.ht/~sthagen/liitos).

## Primary Source repository

The main source of `liitos` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clones of `liitos` are:

* [on codeberg](https://codeberg.org/sthagen/liitos) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/liitos) - a collection of tools useful for software development.

## Contributions

Please do not submit "pull requests" (I found no way to disable that "feature" on GitHub).
If you like to share small changes under the repositories license please kindly do so by sending a patchset.
You can either send such a patchset per email using [git send-email](https://git-send-email.io) or 
if you are a sourcehut user by selecting "Prepare a patchset" on the summary page of your fork at [sourcehut](https://git.sr.ht/).

# Status

Experimental.

**Note**: The default branch is `default`.
